@@ -252,13 +252,14 @@ void test_army (void)
 int create_army (void)
 {
   int ret=-1,i;
+  int fill_table[33]={1, 2, 3, 4, 5, 6, 8, 9, 
+		      10,12,14,16,18,20,22,24,
+		      25,27,29,31,33,36,40,45,
+		      50,55,60,65,70,75,80,90,
+		      99};
 
-  /*
-   * The "battle room" is filled from 2% (1/50 = minimum) to
-   * 66% (33/50 = maximum) depending on the user settings.
-   */
-  CURRENT_ARMY_SIZE= (get_battle_room()
-		      *(LW_CONFIG_CURRENT_RULES.fighter_number+1))/50;
+  CURRENT_ARMY_SIZE= (get_battle_room()*
+		      fill_table[LW_CONFIG_CURRENT_RULES.fighter_number])/100;
 
   CURRENT_ARMY_SIZE/=PLAYING_TEAMS;
   if (CURRENT_ARMY_SIZE<1)
