@@ -107,7 +107,7 @@ typedef struct
    */
   int     key_state;  
   /* true if the player is a computer */
-  int     cpu_or_human;
+  int     control_type;
   /* 
    * true if the player is located on 
    * a remote machine                 
