@@ -85,6 +85,7 @@
 #include "network.h"
 #include "lang.h"
 #include "exit.h"
+#include "capture.h"
 
 /*==================================================================*/
 /* definitions de constantes                                        */
@@ -381,8 +382,8 @@ int blank_round(void)
        */
       init_distorsion_displayer();
       /*
-      * prepares the basic layer for the first buffer
-      */
+       * prepares the basic layer for the first buffer
+       */
       display_back_image();
       rect_for_viewport ();
       /*
@@ -392,12 +393,12 @@ int blank_round(void)
       display_area();
       undisp_all_cursors();
       /*
-      * we now show what we have done to the player
-      */
+       * we now show what we have done to the player
+       */
       page_flip();
       /*
-      * prepares the basic layer for the second buffer
-      */
+       * prepares the basic layer for the second buffer
+       */
       display_back_image();
       rect_for_viewport ();
       /*
@@ -489,13 +490,15 @@ static void logic(void)
    */
   start_profile (SPREAD_PROFILE);
   if (!PAUSE_ON)
-    /*
-     * spreads the gradient, ie calculates in the game area how far
-     * each point is from the cursors, this information depends
-     * on where the cursors are, this information being given
-     * by apply_all_cursor
-     */
-    spread_single_gradient();
+    {
+      /*
+       * spreads the gradient, ie calculates in the game area how far
+       * each point is from the cursors, this information depends
+       * on where the cursors are, this information being given
+       * by apply_all_cursor
+       */
+      spread_single_gradient();
+    }
   /*
    * this call ends the time tracking associated to the spread function
    */
@@ -503,13 +506,27 @@ static void logic(void)
 
   start_profile (MOVE_PROFILE);
   if (!PAUSE_ON)
-    /*
-     * now we move the fighters, ie each fighter of each team
-     * will either move, attack his neighbor, die...
-     */
-    move_fighters();
+    {
+      /*
+       * now we move the fighters, ie each fighter of each team
+       * will either move, attack his neighbor, die...
+       */
+      move_fighters();
+    }
+
   stop_profile (MOVE_PROFILE);
 
+  if (!PAUSE_ON)
+    {
+      /*
+       * we check if a team has lost
+       *
+       * This code used to be in the "display" functions, which
+       * is a very bad idea for it caused network inconsistencies...
+       */
+      check_loose_team();
+    }
+
   /*
    * increments the clock, this way one can know how many game ticks
    * there has been. there's actually no link between this clock
@@ -561,16 +578,6 @@ static void display(void)
    */
   check_info_state();
 
-  /*
-   * we display the system messages if needed
-   */
-  display_message();
-
-  /*
-   * we check if a team has lost
-   */
-  check_loose_team();
-
   /*
    * updates some time values, telling how many weeks this tremendous
    * liquid war session has been running 8-) 
@@ -578,9 +585,31 @@ static void display(void)
   update_play_time();
 
   /*
-   * displays the info bar with the elapsed time etc... if required
+   * Now this is a little trick, we change the order of display
+   * depending on the capture mode.
    */
-  display_info ();
+  if (lw_capture_get_mode())
+    {
+      /*
+       * We're in capture mode: we display info before the dump
+       * for we want it to be there but we display the messages
+       * after the dump since they are ugly and useless in a 
+       * video capture.
+       */
+      display_info ();
+      lw_capture_dump_game();
+      display_message();
+    }
+  else
+    {
+      /*
+       * We're not in capture mode: we display the messages first,
+       * for displaying them after the info might give them an
+       * ugly blinking look if we're not in double-buffered mode.
+       */
+      display_message();
+      display_info ();
+    }
 
   /*
    * it's interesting to know how much time is wasted on page flips
