@@ -91,152 +91,152 @@ static int INFO_BAR_POS_H;
 /*------------------------------------------------------------------*/
 int init_info_bar (int w, int h, int epaisseur)
 {
- int i,x,y;
- BITMAP *front,*back;
+  int i,x,y;
+  BITMAP *front,*back;
 
- if (INFO_BAR)
+  if (INFO_BAR)
     destroy_bitmap (INFO_BAR);
- INFO_BAR=my_create_bitmap(w,h);
- INFO_BAR_BACK=my_create_bitmap(w,h);
+  INFO_BAR=my_create_bitmap(w,h);
+  INFO_BAR_BACK=my_create_bitmap(w,h);
 
- if (INFO_BAR && INFO_BAR_BACK)
+  if (INFO_BAR && INFO_BAR_BACK)
     {
-     if (w>h)
+      if (w>h)
         {
-         rectfill (INFO_BAR,0,0,epaisseur-1,h-1,MENU_BG);
-         vline (INFO_BAR, epaisseur, 0, h-1, MENU_FG);
+	  rectfill (INFO_BAR,0,0,epaisseur-1,h-1,MENU_BG);
+	  vline (INFO_BAR, epaisseur, 0, h-1, MENU_FG);
 
-         front=create_fg_texture(CONFIG_LEVEL_FG);
-         back=create_bg_texture(CONFIG_LEVEL_BG);
+	  front=create_fg_texture(CONFIG_LEVEL_FG);
+	  back=create_bg_texture(CONFIG_LEVEL_BG);
 
-         for (y=0;y<h;y+=front->h)
-             for (x=epaisseur+1;x<w;x+=front->w)
-                 draw_sprite (INFO_BAR,front,x,y);
+	  for (y=0;y<h;y+=front->h)
+	    for (x=epaisseur+1;x<w;x+=front->w)
+	      draw_sprite (INFO_BAR,front,x,y);
 
-         INFO_BAR_POS_W=w-epaisseur-5;
-         INFO_BAR_POS_H=(h-1)/PLAYING_TEAMS-1;
-         for (i=0;i<PLAYING_TEAMS;++i)
-             {
+	  INFO_BAR_POS_W=w-epaisseur-5;
+	  INFO_BAR_POS_H=(h-1)/PLAYING_TEAMS-1;
+	  for (i=0;i<PLAYING_TEAMS;++i)
+	    {
               INFO_BAR_POS_X[i]=epaisseur+3;
               INFO_BAR_POS_Y[i]= (h+1-PLAYING_TEAMS
-                                 *(INFO_BAR_POS_H+1))/2
-                                 +i*(INFO_BAR_POS_H+1);
+				  *(INFO_BAR_POS_H+1))/2
+		+i*(INFO_BAR_POS_H+1);
 
               for (y=INFO_BAR_POS_Y[i];
                    y<INFO_BAR_POS_Y[i]+INFO_BAR_POS_H;
                    y++)
-                  for (x=INFO_BAR_POS_X[i];
-                       x<INFO_BAR_POS_X[i]+INFO_BAR_POS_W;
-                       x++)
-                       putpixel (INFO_BAR,x,y,
-                                getpixel (back,
-                                         (x-epaisseur-1)%back->w,
-                                         y%back->h));
-             }
+		for (x=INFO_BAR_POS_X[i];
+		     x<INFO_BAR_POS_X[i]+INFO_BAR_POS_W;
+		     x++)
+		  putpixel (INFO_BAR,x,y,
+			    getpixel (back,
+				      (x-epaisseur-1)%back->w,
+				      y%back->h));
+	    }
 
-         destroy_bitmap (back);
-         destroy_bitmap (front);
+	  destroy_bitmap (back);
+	  destroy_bitmap (front);
         }
-     else
+      else
         {
-         rectfill (INFO_BAR,0,0,w-1,epaisseur-1,MENU_BG);
-         hline (INFO_BAR, 0, epaisseur, w-1, MENU_FG);
+	  rectfill (INFO_BAR,0,0,w-1,epaisseur-1,MENU_BG);
+	  hline (INFO_BAR, 0, epaisseur, w-1, MENU_FG);
 
-         front=create_fg_texture(CONFIG_LEVEL_FG);
-         back=create_bg_texture(CONFIG_LEVEL_BG);
+	  front=create_fg_texture(CONFIG_LEVEL_FG);
+	  back=create_bg_texture(CONFIG_LEVEL_BG);
 
-         for (y=epaisseur+1;y<h;y+=front->h)
-             for (x=0;x<w;x+=front->w)
-                 draw_sprite (INFO_BAR,front,x,y);
+	  for (y=epaisseur+1;y<h;y+=front->h)
+	    for (x=0;x<w;x+=front->w)
+	      draw_sprite (INFO_BAR,front,x,y);
 
-         INFO_BAR_POS_W=(w-1)/PLAYING_TEAMS-1;
-         INFO_BAR_POS_H=h-epaisseur-5;
-         for (i=0;i<PLAYING_TEAMS;++i)
-             {
+	  INFO_BAR_POS_W=(w-1)/PLAYING_TEAMS-1;
+	  INFO_BAR_POS_H=h-epaisseur-5;
+	  for (i=0;i<PLAYING_TEAMS;++i)
+	    {
               INFO_BAR_POS_X[i]= (w+1-PLAYING_TEAMS
-                                 *(INFO_BAR_POS_W+1))/2
-                                 +i*(INFO_BAR_POS_W+1);
+				  *(INFO_BAR_POS_W+1))/2
+		+i*(INFO_BAR_POS_W+1);
               INFO_BAR_POS_Y[i]=epaisseur+3;
 
               for (y=INFO_BAR_POS_Y[i];
                    y<INFO_BAR_POS_Y[i]+INFO_BAR_POS_H;
                    y++)
-                  for (x=INFO_BAR_POS_X[i];
-                       x<INFO_BAR_POS_X[i]+INFO_BAR_POS_W;
-                       x++)
-                       putpixel (INFO_BAR,x,y,
-                                getpixel (back,
-                                         x%back->w,
-                                         (y-epaisseur-1)%back->h));
-             }
+		for (x=INFO_BAR_POS_X[i];
+		     x<INFO_BAR_POS_X[i]+INFO_BAR_POS_W;
+		     x++)
+		  putpixel (INFO_BAR,x,y,
+			    getpixel (back,
+				      x%back->w,
+				      (y-epaisseur-1)%back->h));
+	    }
 
-         destroy_bitmap (back);
-         destroy_bitmap (front);
+	  destroy_bitmap (back);
+	  destroy_bitmap (front);
         }
-        draw_sprite (INFO_BAR_BACK,INFO_BAR,0,0);
+      draw_sprite (INFO_BAR_BACK,INFO_BAR,0,0);
     }
- return (INFO_BAR&&INFO_BAR_BACK);
+  return (INFO_BAR&&INFO_BAR_BACK);
 }
 
 /*------------------------------------------------------------------*/
 void free_info_bar (void)
 {
- if (INFO_BAR)
+  if (INFO_BAR)
     {
-     destroy_bitmap (INFO_BAR);
-     INFO_BAR=NULL;
+      destroy_bitmap (INFO_BAR);
+      INFO_BAR=NULL;
     }
- if (INFO_BAR_BACK)
+  if (INFO_BAR_BACK)
     {
-     destroy_bitmap (INFO_BAR_BACK);
-     INFO_BAR_BACK=NULL;
+      destroy_bitmap (INFO_BAR_BACK);
+      INFO_BAR_BACK=NULL;
     }
 }
 
 /*------------------------------------------------------------------*/
 static void display_time (int x,int y,int w, int h)
 {
- char buffer[6];
- int min,sec,time;
+  char buffer[6];
+  int min,sec,time;
 
-/* rectfill (screen,x,y,x+w-1,y+h-1,MENU_BG);*/
+  /* rectfill (screen,x,y,x+w-1,y+h-1,MENU_BG);*/
 
- time=TIME_LEFT;
- if (time<0)
+  time=TIME_LEFT;
+  if (time<0)
     time=0;
- min=time/60;
- sec=time%60;
+  min=time/60;
+  sec=time%60;
 
- buffer[0]='0'+min/10;
- buffer[1]='0'+min%10;
- buffer[2]=':';
- buffer[3]='0'+sec/10;
- buffer[4]='0'+sec%10;
- buffer[5]=0;
+  buffer[0]='0'+min/10;
+  buffer[1]='0'+min%10;
+  buffer[2]=':';
+  buffer[3]='0'+sec/10;
+  buffer[4]='0'+sec%10;
+  buffer[5]=0;
 
- textout (INFO_BAR,font,buffer,x+1,y+1,-1);
+  textout (INFO_BAR,font,buffer,x+1,y+1,-1);
 }
 
 /*------------------------------------------------------------------*/
 static void display_horizontal_info (int w, int h,
                                      int epaisseur)
 {
- int i,barre_w,barre_x,barre_y;
+  int i,barre_w,barre_x,barre_y;
 
- display_time (0,0,epaisseur,h);
+  display_time (0,0,epaisseur,h);
 
- for (i=0;i<PLAYING_TEAMS;++i)
+  for (i=0;i<PLAYING_TEAMS;++i)
     {
-     barre_w= (ACTIVE_FIGHTERS[i]*(INFO_BAR_POS_W-1))
-              /CURRENT_ARMY_SIZE+1;
-     barre_x= INFO_BAR_POS_X[i]+INFO_BAR_POS_W-barre_w;
-     barre_y= INFO_BAR_POS_Y[i];
-     rectfill (INFO_BAR,
-               barre_x,
-               barre_y,
-               barre_x+barre_w-1,
-               barre_y+INFO_BAR_POS_H-1,
-               COLOR_FIRST_ENTRY[i]+COLORS_PER_TEAM-1);
+      barre_w= (ACTIVE_FIGHTERS[i]*(INFO_BAR_POS_W-1))
+	/CURRENT_ARMY_SIZE+1;
+      barre_x= INFO_BAR_POS_X[i]+INFO_BAR_POS_W-barre_w;
+      barre_y= INFO_BAR_POS_Y[i];
+      rectfill (INFO_BAR,
+		barre_x,
+		barre_y,
+		barre_x+barre_w-1,
+		barre_y+INFO_BAR_POS_H-1,
+		COLOR_FIRST_ENTRY[i]+COLORS_PER_TEAM-1);
     }
 }
 
@@ -244,115 +244,173 @@ static void display_horizontal_info (int w, int h,
 static void display_vertical_info (int w, int h,
                                    int epaisseur)
 {
- int i,barre_h,barre_x,barre_y;
+  int i,barre_h,barre_x,barre_y;
 
- display_time (0,0,w,epaisseur);
+  display_time (0,0,w,epaisseur);
 
- for (i=0;i<PLAYING_TEAMS;++i)
+  for (i=0;i<PLAYING_TEAMS;++i)
     {
-     barre_h= (ACTIVE_FIGHTERS[i]*(INFO_BAR_POS_H-1))
-              /CURRENT_ARMY_SIZE+1;
-     barre_y= INFO_BAR_POS_Y[i]+INFO_BAR_POS_H-barre_h;
-     barre_x= INFO_BAR_POS_X[i];
-     rectfill (INFO_BAR,
-               barre_x,
-               barre_y,
-               barre_x+INFO_BAR_POS_W-1,
-               barre_y+barre_h-1,
-               COLOR_FIRST_ENTRY[i]+COLORS_PER_TEAM-1);
+      barre_h= (ACTIVE_FIGHTERS[i]*(INFO_BAR_POS_H-1))
+	/CURRENT_ARMY_SIZE+1;
+      barre_y= INFO_BAR_POS_Y[i]+INFO_BAR_POS_H-barre_h;
+      barre_x= INFO_BAR_POS_X[i];
+      rectfill (INFO_BAR,
+		barre_x,
+		barre_y,
+		barre_x+INFO_BAR_POS_W-1,
+		barre_y+barre_h-1,
+		COLOR_FIRST_ENTRY[i]+COLORS_PER_TEAM-1);
     }
 }
 
 /*------------------------------------------------------------------*/
 void display_info (void)
 {
- int x,y,w,h,epaisseur,temp_h,temp_w;
+  int x,y,w,h,epaisseur,temp_h,temp_w;
 
- temp_w=text_length(font,"00:00")+2;
- temp_h=text_height(font)+2;
-
- if (!(CONFIG_INFO_BAR&4))
+  if (!(CONFIG_INFO_BAR&4))
     {
-     switch (CONFIG_INFO_BAR)
-            {
-             case 0:
-             case 2: w=SCREEN_W;
-                     h=temp_h;
-                     if (h<13)
-                        h=13;
-                     epaisseur=temp_w;
-                     break;
-             case 1:
-             default: w=temp_w;
-                     if (w<13)
-                        w=13;
-                     h=SCREEN_H;
-                     epaisseur=temp_h;
-                     break;
-            }
+      temp_w=text_length(font,"00:00")+2;
+      temp_h=text_height(font)+2;
 
-     if (!INFO_BAR)
+      switch (CONFIG_INFO_BAR)
+	{
+	case 0:
+	case 2: w=SCREEN_W;
+	  h=temp_h;
+	  if (h<13)
+	    h=13;
+	  epaisseur=temp_w;
+	  break;
+	case 1:
+	default: w=temp_w;
+	  if (w<13)
+	    w=13;
+	  h=SCREEN_H;
+	  epaisseur=temp_h;
+	  break;
+	}
+
+      if (!INFO_BAR)
         init_info_bar(w,h,epaisseur);
 
-     draw_sprite (INFO_BAR,INFO_BAR_BACK,0,0);
+      draw_sprite (INFO_BAR,INFO_BAR_BACK,0,0);
 
-     switch (CONFIG_INFO_BAR)
-            {
-             case 0: x=0;
-                     y=PAGE_FLIP_H;
-                     hline (screen,x,y+h,x+w-1,MENU_FG);
-                     display_horizontal_info (w,h,epaisseur);
-                     break;
-             case 1: x=SCREEN_W-w;
-                     y=PAGE_FLIP_H;
-                     vline (screen,x-1,y,y+h-1,MENU_FG);
-                     display_vertical_info (w,h,epaisseur);
-                     break;
-             case 2: x=0;
-                     y=PAGE_FLIP_H+SCREEN_H-h;
-                     hline (screen,x,y-1,x+w-1,MENU_FG);
-                     display_horizontal_info (w,h,epaisseur);
-                     break;
-             default: x=0;
-                     y=PAGE_FLIP_H;
-                     vline (screen,x+w,y,y+h-1,MENU_FG);
-                     display_vertical_info (w,h,epaisseur);
-                     break;
-            }
-     draw_sprite(screen,INFO_BAR,x,y);
+      switch (CONFIG_INFO_BAR)
+	{
+	case 0: x=0;
+	  y=PAGE_FLIP_H;
+	  hline (screen,x,y+h,x+w-1,MENU_FG);
+	  display_horizontal_info (w,h,epaisseur);
+	  break;
+	case 1: x=SCREEN_W-w;
+	  y=PAGE_FLIP_H;
+	  vline (screen,x-1,y,y+h-1,MENU_FG);
+	  display_vertical_info (w,h,epaisseur);
+	  break;
+	case 2: x=0;
+	  y=PAGE_FLIP_H+SCREEN_H-h;
+	  hline (screen,x,y-1,x+w-1,MENU_FG);
+	  display_horizontal_info (w,h,epaisseur);
+	  break;
+	default: x=0;
+	  y=PAGE_FLIP_H;
+	  vline (screen,x+w,y,y+h-1,MENU_FG);
+	  display_vertical_info (w,h,epaisseur);
+	  break;
+	}
+      draw_sprite(screen,INFO_BAR,x,y);
+    }
+}
+
+/*------------------------------------------------------------------*/
+void lw_info_get_room_for_viewport (int *x, int *y,int *w, int *h)
+{
+  int temp_h,temp_w;
+
+  if (!(CONFIG_INFO_BAR&4))
+    {
+      temp_w=text_length(font,"00:00")+2;
+      temp_h=text_height(font)+2;
+    
+      if (temp_h<13) 
+	{
+	  temp_h=13;
+	}
+
+      if (temp_w<13) 
+	{
+	  temp_w=13;
+	}
+
+      switch (CONFIG_INFO_BAR)
+	{
+	case 0: 
+	  *x=0;
+	  *y=temp_h+1;
+	  *w=SCREEN_W;
+	  *h=SCREEN_H-temp_h-1;
+	  break;
+	case 1: 
+	  *x=0;
+	  *y=0;
+	  *w=SCREEN_W-temp_w-1;
+	  *h=SCREEN_H;
+	  break;
+	case 2: 
+	  *x=0;
+	  *y=0;
+	  *w=SCREEN_W;
+	  *h=SCREEN_H-temp_h-1;	       
+	  break;
+	default: 
+	  *x=temp_w+1;
+	  *y=0;
+	  *w=SCREEN_W-temp_w-1;
+	  *h=SCREEN_H;
+	  break;
+	}
+    }
+  else
+    {
+      *x=0;
+      *y=0;
+      *w=SCREEN_W;
+      *h=SCREEN_H;
     }
 }
 
 /*------------------------------------------------------------------*/
 void check_info_state (void)
 {
- static int changed;
+  static int changed;
 
- if (WATCHDOG_SCANCODE[KEY_F1])
+  if (WATCHDOG_SCANCODE[KEY_F1])
     {
-     if (CONFIG_INFO_BAR>=4)
+      if (CONFIG_INFO_BAR>=4)
         CONFIG_INFO_BAR-=4;
-     else
-         CONFIG_INFO_BAR+=4;
-     free_info_bar();
-     changed=CONFIG_PAGE_FLIP ? 2 : 1;
+      else
+	CONFIG_INFO_BAR+=4;
+      free_info_bar();
+      changed=CONFIG_PAGE_FLIP ? 2 : 1;
+      lw_viewport_register_change(changed);
     }
- if (WATCHDOG_SCANCODE[KEY_F2] && CONFIG_INFO_BAR<4)
+  if (WATCHDOG_SCANCODE[KEY_F2] && CONFIG_INFO_BAR<4)
     {
-     CONFIG_INFO_BAR++;
-     if (CONFIG_INFO_BAR==4)
+      CONFIG_INFO_BAR++;
+      if (CONFIG_INFO_BAR==4)
         CONFIG_INFO_BAR=0;
-     if (CONFIG_INFO_BAR==8)
+      if (CONFIG_INFO_BAR==8)
         CONFIG_INFO_BAR=4;
-     free_info_bar();
-     changed=CONFIG_PAGE_FLIP ? 2 : 1;
+      free_info_bar();
+      changed=CONFIG_PAGE_FLIP ? 2 : 1;
+      lw_viewport_register_change(changed);
     }
 
- if (changed>0)
+  if (changed>0)
     {
-     display_back_image();
-     rect_for_viewport ();
-     changed--;
+      display_back_image();
+      changed--;
     }
 }
 
