@@ -179,6 +179,23 @@ int internet_find (void)
 
       choix=my_do_dialog (d,choix);
 
+      /*
+       * First test to select the current list value if
+       * it exists, and make it the current server.
+       */
+      cur=d[4].d1;
+      if (choix == MENU_QUICK_PLAY ||
+	  choix == 4 ||
+	  choix == 6)
+	{
+	  if (cur>=0 && cur<size)
+	    {
+	      strncpy(CONFIG_SERVER_ADDRESS,data[cur].ip,SERVER_ADDRESS_SIZE);
+	      CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE]='\0';
+	      CONFIG_SERVER_PORT=data[cur].port;
+	    }
+	}
+
       switch (choix)
 	{
 	case -1:
@@ -195,7 +212,7 @@ int internet_find (void)
 	    display_back_image();
 	  break;
 	case MENU_QUICK_PLAY:
-	  retour=MENU_PLAY;
+	  retour=netplay_sequence();
 	  break;
 	case 5:
 	  size=LW_INTERNET_LIST_SIZE;
@@ -203,12 +220,8 @@ int internet_find (void)
 	  break;
 	case 4:
 	case 6:
-	  cur=d[4].d1;
 	  if (cur>=0 && cur<size)
 	    {
-	      strncpy(CONFIG_SERVER_ADDRESS,data[cur].ip,SERVER_ADDRESS_SIZE);
-	      CONFIG_SERVER_ADDRESS[SERVER_ADDRESS_SIZE]='\0';
-	      CONFIG_SERVER_PORT=data[cur].port;
 	      retour=netplay_sequence();
 	    }
 	  break;
@@ -307,33 +320,51 @@ char *list_callback(int index, int *size)
 /*------------------------------------------------------------------*/
 void update_text_port (DIALOG *d,int i)
 {
-  if (i>=0 && i<*list_size)
+  if (i>=0) 
     {
-      sprintf(d->dp,
-	      "%s: %d",
-	      lw_lang_string(LW_LANG_STRING_INTERNET_PORT),
-	      list_data[i].port);
+      if (i<*list_size)
+	{
+	  sprintf(d->dp,
+		  "%s: %d",
+		  lw_lang_string(LW_LANG_STRING_INTERNET_PORT),
+		  list_data[i].port);
+	}
+      else
+	{
+	  sprintf(d->dp,
+		  "%s:",
+		  lw_lang_string(LW_LANG_STRING_INTERNET_PORT));
+	}
     }
 }
 
 /*------------------------------------------------------------------*/
 void update_text_password (DIALOG *d,int i)
 {
-  if (i>=0 && i<*list_size)
+  if (i>=0)
     {
-      if (list_data[i].password)
+      if (i<*list_size)
 	{
-	  sprintf(d->dp,
-		  "%s: %s",
-		  lw_lang_string(LW_LANG_STRING_INTERNET_PASSWORD),
-		  lw_lang_string(LW_LANG_STRING_INTERNET_YES));
+	  if (list_data[i].password)
+	    {
+	      sprintf(d->dp,
+		      "%s: %s",
+		      lw_lang_string(LW_LANG_STRING_INTERNET_PASSWORD),
+		      lw_lang_string(LW_LANG_STRING_INTERNET_YES));
+	    }
+	  else
+	    {
+	      sprintf(d->dp,
+		      "%s: %s",
+		      lw_lang_string(LW_LANG_STRING_INTERNET_PASSWORD),
+		      lw_lang_string(LW_LANG_STRING_INTERNET_NO));
+	    }
 	}
       else
 	{
 	  sprintf(d->dp,
-		  "%s: %s",
-		  lw_lang_string(LW_LANG_STRING_INTERNET_PASSWORD),
-		  lw_lang_string(LW_LANG_STRING_INTERNET_NO));
+		  "%s:",
+		  lw_lang_string(LW_LANG_STRING_INTERNET_PASSWORD));
 	}
     }
 }
@@ -343,53 +374,62 @@ void update_text_uptime (DIALOG *d,int i)
 {
   int days,hours,minutes,seconds;
 
-  if (i>=0 && i<*list_size)
+  if (i>=0)
     {
-      seconds=list_data[i].uptime%60;
-      minutes=(list_data[i].uptime/60)%60;
-      hours=(list_data[i].uptime/3600)%24;
-      days=(list_data[i].uptime/(24*3600));
-      if (days>0)
+      if (i<*list_size)
 	{
-	  if (days>1)
+	  seconds=list_data[i].uptime%60;
+	  minutes=(list_data[i].uptime/60)%60;
+	  hours=(list_data[i].uptime/3600)%24;
+	  days=(list_data[i].uptime/(24*3600));
+	  if (days>0)
+	    {
+	      if (days>1)
+		{
+		  sprintf(d->dp,
+			  "%s: %d %s",
+			  lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
+			  days,
+			  lw_lang_string(LW_LANG_STRING_INTERNET_DAYS));
+		}
+	      else
+		{
+		  sprintf(d->dp,
+			  "%s: 1 %s",
+			  lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
+			  lw_lang_string(LW_LANG_STRING_INTERNET_DAY));
+		}
+	    }
+	  else if (hours>0)
 	    {
 	      sprintf(d->dp,
 		      "%s: %d %s",
 		      lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
-		      days,
-		      lw_lang_string(LW_LANG_STRING_INTERNET_DAYS));
+		      hours,
+		      lw_lang_string(LW_LANG_STRING_INTERNET_HOURS));
+	    }
+	  else if (minutes>0)
+	    {
+	      sprintf(d->dp,
+		      "%s: %d %s",
+		      lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
+		      minutes,
+		      lw_lang_string(LW_LANG_STRING_INTERNET_MINUTES));
 	    }
 	  else
 	    {
 	      sprintf(d->dp,
-		      "%s: 1 %s",
+		      "%s: %d %s",
 		      lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
-		      lw_lang_string(LW_LANG_STRING_INTERNET_DAY));
+		      seconds,
+		      lw_lang_string(LW_LANG_STRING_INTERNET_SECONDS));
 	    }
 	}
-      else if (hours>0)
-	{
-	  sprintf(d->dp,
-		  "%s: %d %s",
-		  lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
-		  hours,
-		  lw_lang_string(LW_LANG_STRING_INTERNET_HOURS));
-	}
-      else if (minutes>0)
-	{
-	  sprintf(d->dp,
-		  "%s: %d %s",
-		  lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
-		  minutes,
-		  lw_lang_string(LW_LANG_STRING_INTERNET_MINUTES));
-	}
       else
 	{
 	  sprintf(d->dp,
-		  "%s: %d %s",
-		  lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME),
-		  seconds,
-		  lw_lang_string(LW_LANG_STRING_INTERNET_SECONDS));
+		  "%s:",
+		  lw_lang_string(LW_LANG_STRING_INTERNET_UPTIME));
 	}
     }
 }
@@ -397,8 +437,15 @@ void update_text_uptime (DIALOG *d,int i)
 /*------------------------------------------------------------------*/
 void update_text_comment (DIALOG *d,int i)
 {
-  if (i>=0 && i<*list_size)
+  if (i>=0)
     {
-      sprintf(d->dp,"%s",list_data[i].comment);
+      if (i<*list_size)
+	{
+	  sprintf(d->dp,"%s",list_data[i].comment);
+	}
+      else
+	{
+	  strcpy(d->dp,"");
+	}
     }
 }
