@@ -180,12 +180,18 @@ void wait_no_key (void)
 {
   int touched,i;
   int start_tick;
+  int dummy;
 
   start_tick=get_ticker();
 
   lw_mouse_reset_control ();
   do
     {
+      /*
+       * Force a all to poll_keyboard if needed
+       */
+      dummy=keypressed();
+
       touched=0;
       lw_mouse_update_control ();
       my_poll_joystick ();
@@ -202,6 +208,7 @@ int wait_key_pressed (void)
 {
   int touched=0,i,result=0;
   int start_tick;
+  int dummy;
 
   start_tick=get_ticker();
 
@@ -209,6 +216,11 @@ int wait_key_pressed (void)
   while ((!touched) && 
 	 get_ticker()<start_tick+LW_KEYBOARD_WAITKEYPRESSED_TICK_LIMIT)
     {
+      /*
+       * Force a all to poll_keyboard if needed
+       */
+      dummy=keypressed();
+
       lw_mouse_update_control ();
       my_poll_joystick ();
       for (i=0;i<256 && !touched;++i)
