@@ -51,6 +51,10 @@
 /* includes                                                         */
 /*==================================================================*/
 
+#ifdef WIN32
+#include <windows.h>
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -160,9 +164,35 @@ int lw_lang_auto()
 #endif
 
 #ifdef WIN32
-  /*
-   * Need to find a way to get Language under Win32
-   */
+  {
+    int lang_id;
+
+    lang_id=GetSystemDefaultLangID();
+
+    /*
+     * Lists of some Windows language codes, 
+     * got it online on msdn.microsoft.com
+     *
+     * 0x040c French (Standard) 
+     * 0x080c French (Belgian) 
+     * 0x0c0c French (Canadian) 
+     * 0x100c French (Switzerland) 
+     * 0x140c French (Luxembourg) 
+     * 0x180c Windows 98/Me, Windows 2000/XP: French (Monaco)
+     */
+    
+    switch (lang_id)
+      {
+      case 0x040c:
+      case 0x080c:
+      case 0x0c0c:
+      case 0x100c:
+      case 0x140c:
+      case 0x180c:
+	language=LW_LANG_LANGUAGE_FRANCAIS;
+	break;
+      }
+  }
 #endif
 
   return language;
