@@ -64,6 +64,33 @@
 /* constants                                                        */
 /*==================================================================*/
 
+#define LW_NETCONF_CONFIG config
+#define LW_NETCONF_TEXT_cursor_increase_speed "cursor_increase_speed"
+#define LW_NETCONF_MAX_cursor_increase_speed 2
+
+/*==================================================================*/
+/* macros                                                           */
+/*==================================================================*/
+
+#define LW_NETCONF_CHECK_RANGE(VAL,MAX) \
+if (config-> ## VAL < 0) \
+{ \
+result=0; \
+log_print_str("Error: " #VAL " is "); \
+log_print_int(config-> ## VAL); \
+log_println_str(", and should be >= 0"); \
+config-> ## VAL = 0; \
+} \
+if (config-> ## VAL > MAX) \
+{ \
+result=0; \
+log_print_str("Error: " #VAL " is > "); \
+log_print_int(config-> ## VAL); \
+log_print_str(", and should be <= "); \
+log_println_int(MAX); \
+config-> ## VAL = MAX; \
+}
+
 /*==================================================================*/
 /* types                                                            */
 /*==================================================================*/
@@ -188,3 +215,23 @@ int lw_netconf_recv(int sock, LW_NETCONF *config)
   return result;
 }
 
+/*------------------------------------------------------------------*/
+/*
+ * Checks if all the values are within an acceptable range
+ */
+int lw_netconf_check(LW_NETCONF *config)
+{
+  int result=1;
+
+  LW_NETCONF_CHECK_RANGE(cursor_increase_speed,2);
+  LW_NETCONF_CHECK_RANGE(fighter_attack,16);
+  LW_NETCONF_CHECK_RANGE(fighter_defense,16);
+  LW_NETCONF_CHECK_RANGE(fighter_new_health,16);
+  LW_NETCONF_CHECK_RANGE(number_influence,16);
+  LW_NETCONF_CHECK_RANGE(fighter_number,32);
+  LW_NETCONF_CHECK_RANGE(game_time,16);
+  LW_NETCONF_CHECK_RANGE(cpu_advantage,4);
+  LW_NETCONF_CHECK_RANGE(asm_algorithm,1);
+
+  return result;
+}
