@@ -74,6 +74,8 @@ extern int STARTUP_SVGA;
 extern int STARTUP_STOP;
 extern int STARTUP_AUTO;
 extern int STARTUP_CHECK;
+extern int STARTUP_CAPTURE;
+extern int STARTUP_TOMBOLA;
 
 extern char STARTUP_CFG_PATH[];
 extern char STARTUP_DAT_PATH[];
